# Generated by Django 3.2.4 on 2022-01-08 21:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Agency',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=30, null=True, verbose_name='Ajénsia')),
            ],
            options={
                'verbose_name_plural': 'Dadus Custom Ba Ajénsia',
            },
        ),
        migrations.CreateModel(
            name='Company',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=300, null=True)),
            ],
            options={
                'verbose_name_plural': ' Dadus Custom Ba Kompañia',
            },
        ),
        migrations.CreateModel(
            name='National',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, null=True, verbose_name='Nasional')),
                ('code', models.CharField(blank=True, max_length=10, null=True)),
            ],
            options={
                'verbose_name_plural': 'Dadus Custom Ba Nasional',
            },
        ),
        migrations.CreateModel(
            name='ONG',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=30, null=True, verbose_name='ONG')),
            ],
            options={
                'verbose_name_plural': 'Dadus Custom Ba ONG',
            },
        ),
    ]
